==> endstone-0.2.0.tar.gz: endstone-0.2.0/include/endstone/detail/permissions/default_permissions.h <==
// Copyright (c) 2024, The Endstone Project. (https://endstone.dev) All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#pragma once

#include <memory>
#include <string>
#include <unordered_map>

#include "endstone/detail/server.h"
#include "endstone/detail/singleton.h"
#include "endstone/permissions/permissions.h"

namespace endstone::detail {

class DefaultPermissions {
public:
    static Permission *registerPermission(std::unique_ptr<Permission> perm, Permission *parent = nullptr);

    static Permission *registerPermission(const std::string &name, Permission *parent = nullptr,
                                          const std::string &desc = "",
                                          PermissionDefault default_value = Permission::DEFAULT_PERMISSION,
                                          const std::unordered_map<std::string, bool> &children = {});
    static void registerCorePermissions();
    static void registerCommandPermissions(Permission *parent);
};

}  // namespace endstone::detail

==> endstone-0.3.0.tar.gz: endstone-0.3.0/include/endstone/detail/permissions/default_permissions.h <==
// Copyright (c) 2024, The Endstone Project. (https://endstone.dev) All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#pragma once

#include <memory>
#include <string>
#include <unordered_map>

#include "endstone/detail/server.h"
#include "endstone/detail/singleton.h"
#include "endstone/permissions/permission.h"

namespace endstone::detail {

class DefaultPermissions {
public:
    static Permission *registerPermission(std::unique_ptr<Permission> perm, Permission *parent = nullptr);

    static Permission *registerPermission(const std::string &name, Permission *parent = nullptr,
                                          const std::string &desc = "",
                                          PermissionDefault default_value = Permission::DEFAULT_PERMISSION,
                                          const std::unordered_map<std::string, bool> &children = {});
    static void registerCorePermissions();
    static void registerCommandPermissions(Permission *parent);
};

}  // namespace endstone::detail
